@@ -2,7 +2,7 @@
 
 import jaraco.abode
 from jaraco.abode.helpers import urls
-import jaraco.abode.helpers.constants as CONST
+import jaraco.abode.devices.status as STATUS
 
 import pytest
 
@@ -23,12 +23,12 @@ class TestDoorLock:
         m.post(urls.LOGIN, json=LOGIN.post_response_ok())
         m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
         m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
-        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode='standby'))
         m.get(
             urls.DEVICES,
             json=DOOR_LOCK.device(
                 devid=DOOR_LOCK.DEVICE_ID,
-                status=CONST.STATUS_LOCKCLOSED,
+                status=STATUS.Lock.CLOSED,
                 low_battery=False,
                 no_response=False,
             ),
@@ -42,7 +42,7 @@ class TestDoorLock:
 
         # Test our device
         assert device is not None
-        assert device.status == CONST.STATUS_LOCKCLOSED
+        assert device.status == STATUS.Lock.CLOSED
         assert not device.battery_low
         assert not device.no_response
         assert device.is_locked
@@ -55,7 +55,7 @@ class TestDoorLock:
             device_url,
             json=DOOR_LOCK.device(
                 devid=DOOR_LOCK.DEVICE_ID,
-                status=CONST.STATUS_LOCKOPEN,
+                status=STATUS.Lock.OPEN,
                 low_battery=True,
                 no_response=True,
             ),
@@ -64,7 +64,7 @@ class TestDoorLock:
         # Refesh device and test changes
         device.refresh()
 
-        assert device.status == CONST.STATUS_LOCKOPEN
+        assert device.status == STATUS.Lock.OPEN
         assert device.battery_low
         assert device.no_response
         assert not device.is_locked
@@ -75,12 +75,12 @@ class TestDoorLock:
         m.post(urls.LOGIN, json=LOGIN.post_response_ok())
         m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
         m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
-        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode='standby'))
         m.get(
             urls.DEVICES,
             json=DOOR_LOCK.device(
                 devid=DOOR_LOCK.DEVICE_ID,
-                status=CONST.STATUS_LOCKCLOSED,
+                status=STATUS.Lock.CLOSED,
                 low_battery=False,
                 no_response=False,
             ),
@@ -94,7 +94,7 @@ class TestDoorLock:
 
         # Test that we have our device
         assert device is not None
-        assert device.status == CONST.STATUS_LOCKCLOSED
+        assert device.status == STATUS.Lock.CLOSED
         assert device.is_locked
 
         # Set up control url response
@@ -102,33 +102,33 @@ class TestDoorLock:
         m.put(
             control_url,
             json=DEVICES.status_put_response_ok(
-                devid=DOOR_LOCK.DEVICE_ID, status=CONST.STATUS_LOCKOPEN_INT
+                devid=DOOR_LOCK.DEVICE_ID, status=int(STATUS.Lock.OPEN)
             ),
         )
 
         # Change the mode to "on"
         assert device.unlock()
-        assert device.status == CONST.STATUS_LOCKOPEN
+        assert device.status == STATUS.Lock.OPEN
         assert not device.is_locked
 
         # Change response
         m.put(
             control_url,
             json=DEVICES.status_put_response_ok(
-                devid=DOOR_LOCK.DEVICE_ID, status=CONST.STATUS_LOCKCLOSED_INT
+                devid=DOOR_LOCK.DEVICE_ID, status=int(STATUS.Lock.CLOSED)
             ),
         )
 
         # Change the mode to "off"
         assert device.lock()
-        assert device.status == CONST.STATUS_LOCKCLOSED
+        assert device.status == STATUS.Lock.CLOSED
         assert device.is_locked
 
         # Test that an invalid status response throws exception
         m.put(
             control_url,
             json=DEVICES.status_put_response_ok(
-                devid=DOOR_LOCK.DEVICE_ID, status=CONST.STATUS_LOCKCLOSED_INT
+                devid=DOOR_LOCK.DEVICE_ID, status=int(STATUS.Lock.CLOSED)
             ),
         )
 
