@@ -5,7 +5,7 @@ import pytest
 
 import jaraco.abode
 from jaraco.abode.helpers import urls
-import jaraco.abode.helpers.constants as CONST
+import jaraco.abode.devices.status as STATUS
 import jaraco.abode.helpers.timeline as TIMELINE
 from jaraco.abode.devices.binary_sensor import BinarySensor
 
@@ -27,12 +27,12 @@ class TestEventController:
         m.post(urls.LOGIN, json=LOGIN.post_response_ok())
         m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
         m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
-        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode='standby'))
         m.get(
             urls.DEVICES,
             json=COVER.device(
                 devid=COVER.DEVICE_ID,
-                status=CONST.STATUS_CLOSED,
+                status=STATUS.CLOSED,
                 low_battery=False,
                 no_response=False,
             ),
@@ -61,12 +61,12 @@ class TestEventController:
         m.post(urls.LOGIN, json=LOGIN.post_response_ok())
         m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
         m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
-        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode='standby'))
         m.get(
             urls.DEVICES,
             json=COVER.device(
                 devid=COVER.DEVICE_ID,
-                status=CONST.STATUS_CLOSED,
+                status=STATUS.CLOSED,
                 low_battery=False,
                 no_response=False,
             ),
@@ -92,12 +92,12 @@ class TestEventController:
         m.post(urls.LOGIN, json=LOGIN.post_response_ok())
         m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
         m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
-        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode='standby'))
         m.get(
             urls.DEVICES,
             json=COVER.device(
                 devid=COVER.DEVICE_ID,
-                status=CONST.STATUS_CLOSED,
+                status=STATUS.CLOSED,
                 low_battery=False,
                 no_response=False,
             ),
@@ -126,12 +126,12 @@ class TestEventController:
         m.post(urls.LOGIN, json=LOGIN.post_response_ok())
         m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
         m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
-        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode='standby'))
         m.get(
             urls.DEVICES,
             json=COVER.device(
                 devid=COVER.DEVICE_ID,
-                status=CONST.STATUS_CLOSED,
+                status=STATUS.CLOSED,
                 low_battery=False,
                 no_response=False,
             ),
@@ -166,12 +166,12 @@ class TestEventController:
         m.post(urls.LOGIN, json=LOGIN.post_response_ok())
         m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
         m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
-        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode='standby'))
         m.get(
             urls.DEVICES,
             json=COVER.device(
                 devid=COVER.DEVICE_ID,
-                status=CONST.STATUS_CLOSED,
+                status=STATUS.CLOSED,
                 low_battery=False,
                 no_response=False,
             ),
@@ -245,12 +245,12 @@ class TestEventController:
         m.post(urls.LOGIN, json=LOGIN.post_response_ok())
         m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
         m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
-        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode='standby'))
         m.get(
             urls.DEVICES,
             json=COVER.device(
                 devid=COVER.DEVICE_ID,
-                status=CONST.STATUS_CLOSED,
+                status=STATUS.CLOSED,
                 low_battery=False,
                 no_response=False,
             ),
@@ -278,7 +278,7 @@ class TestEventController:
             device_url,
             json=COVER.device(
                 devid=COVER.DEVICE_ID,
-                status=CONST.STATUS_OPEN,
+                status=STATUS.OPEN,
                 low_battery=False,
                 no_response=False,
             ),
@@ -290,7 +290,7 @@ class TestEventController:
         callback.assert_called_with(device)
 
         # Test that our device updated
-        assert device.status == CONST.STATUS_OPEN
+        assert device.status == STATUS.OPEN
 
         # Test that no device ID cleanly returns
         events._on_device_update(None)
@@ -362,12 +362,12 @@ class TestEventController:
         m.post(urls.LOGIN, json=LOGIN.post_response_ok())
         m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
         m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
-        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode='standby'))
         m.get(
             urls.DEVICES,
             json=COVER.device(
                 devid=COVER.DEVICE_ID,
-                status=CONST.STATUS_CLOSED,
+                status=STATUS.CLOSED,
                 low_battery=False,
                 no_response=False,
             ),
@@ -391,11 +391,11 @@ class TestEventController:
 
         # Call our mode changed callback method
 
-        events._on_mode_change(CONST.MODE_HOME)
+        events._on_mode_change('home')
         callback.assert_called_with(alarm)
 
         # Test that our alarm state is set properly
-        assert alarm.mode == CONST.MODE_HOME
+        assert alarm.mode == 'home'
 
         # Test that no mode cleanly returns
         events._on_mode_change(None)
@@ -427,19 +427,17 @@ class TestEventController:
         m.post(urls.LOGIN, json=LOGIN.post_response_ok())
         m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
         m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
-        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode='standby'))
         m.get(
             urls.DEVICES,
             json=[
                 COVER.device(
                     devid=COVER.DEVICE_ID,
-                    status=CONST.STATUS_CLOSED,
+                    status=STATUS.CLOSED,
                     low_battery=False,
                     no_response=False,
                 ),
-                DOORCONTACT.device(
-                    devid=DOORCONTACT.DEVICE_ID, status=CONST.STATUS_CLOSED
-                ),
+                DOORCONTACT.device(devid=DOORCONTACT.DEVICE_ID, status=STATUS.CLOSED),
             ],
         )
 
@@ -468,7 +466,7 @@ class TestEventController:
             cover_url,
             json=COVER.device(
                 devid=COVER.DEVICE_ID,
-                status=CONST.STATUS_OPEN,
+                status=STATUS.OPEN,
                 low_battery=False,
                 no_response=False,
             ),
@@ -477,7 +475,7 @@ class TestEventController:
         door_url = urls.DEVICE.format(device_id=DOORCONTACT.DEVICE_ID)
         m.get(
             door_url,
-            json=DOORCONTACT.device(devid=COVER.DEVICE_ID, status=CONST.STATUS_OPEN),
+            json=DOORCONTACT.device(devid=COVER.DEVICE_ID, status=STATUS.OPEN),
         )
 
         # Call our device callback method for our cover
@@ -486,17 +484,17 @@ class TestEventController:
         callback.assert_called_with(cover)
 
         # Test that our device updated
-        assert cover.status == CONST.STATUS_OPEN
+        assert cover.status == STATUS.OPEN
 
         # Test that our other device didn't update
-        assert doorcontact.status == CONST.STATUS_CLOSED
+        assert doorcontact.status == STATUS.CLOSED
 
         # Call our device callback method for our door contact
         events._on_device_update(doorcontact.id)
         callback.assert_has_calls([call(cover), call(doorcontact)])
 
         # Test that our door updated now
-        assert doorcontact.status == CONST.STATUS_OPEN
+        assert doorcontact.status == STATUS.OPEN
 
     def test_multi_events_callback(self):
         """Tests that multiple event updates callback correctly."""
