@@ -4,7 +4,7 @@ import pytest
 
 import jaraco.abode
 from jaraco.abode.helpers import urls
-import jaraco.abode.helpers.constants as CONST
+import jaraco.abode.devices.status as STATUS
 
 from .mock import login as LOGIN
 from .mock import oauth_claims as OAUTH_CLAIMS
@@ -23,12 +23,12 @@ class TestPowerSwitchSensor:
         m.post(urls.LOGIN, json=LOGIN.post_response_ok())
         m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
         m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
-        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode='standby'))
         m.get(
             urls.DEVICES,
             json=POWERSENSOR.device(
                 devid=POWERSENSOR.DEVICE_ID,
-                status=CONST.STATUS_OFF,
+                status=STATUS.OFF,
                 low_battery=False,
                 no_response=False,
             ),
@@ -42,7 +42,7 @@ class TestPowerSwitchSensor:
 
         # Test our device
         assert device is not None
-        assert device.status == CONST.STATUS_OFF
+        assert device.status == STATUS.OFF
         assert not device.battery_low
         assert not device.no_response
         assert not device.is_on
@@ -55,7 +55,7 @@ class TestPowerSwitchSensor:
             device_url,
             json=POWERSENSOR.device(
                 devid=POWERSENSOR.DEVICE_ID,
-                status=CONST.STATUS_ON,
+                status=STATUS.ON,
                 low_battery=True,
                 no_response=True,
             ),
@@ -64,7 +64,7 @@ class TestPowerSwitchSensor:
         # Refesh device and test changes
         device.refresh()
 
-        assert device.status == CONST.STATUS_ON
+        assert device.status == STATUS.ON
         assert device.battery_low
         assert device.no_response
         assert device.is_on
@@ -75,12 +75,12 @@ class TestPowerSwitchSensor:
         m.post(urls.LOGIN, json=LOGIN.post_response_ok())
         m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
         m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
-        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode='standby'))
         m.get(
             urls.DEVICES,
             json=POWERSENSOR.device(
                 devid=POWERSENSOR.DEVICE_ID,
-                status=CONST.STATUS_OFF,
+                status=STATUS.OFF,
                 low_battery=False,
                 no_response=False,
             ),
@@ -94,7 +94,7 @@ class TestPowerSwitchSensor:
 
         # Test that we have our device
         assert device is not None
-        assert device.status == CONST.STATUS_OFF
+        assert device.status == STATUS.OFF
         assert not device.is_on
 
         # Set up control url response
@@ -102,33 +102,33 @@ class TestPowerSwitchSensor:
         m.put(
             control_url,
             json=DEVICES.status_put_response_ok(
-                devid=POWERSENSOR.DEVICE_ID, status=CONST.STATUS_ON_INT
+                devid=POWERSENSOR.DEVICE_ID, status=int(STATUS.ON)
             ),
         )
 
         # Change the mode to "on"
         assert device.switch_on()
-        assert device.status == CONST.STATUS_ON
+        assert device.status == STATUS.ON
         assert device.is_on
 
         # Change response
         m.put(
             control_url,
             json=DEVICES.status_put_response_ok(
-                devid=POWERSENSOR.DEVICE_ID, status=CONST.STATUS_OFF_INT
+                devid=POWERSENSOR.DEVICE_ID, status=int(STATUS.OFF)
             ),
         )
 
         # Change the mode to "off"
         assert device.switch_off()
-        assert device.status == CONST.STATUS_OFF
+        assert device.status == STATUS.OFF
         assert not device.is_on
 
         # Test that an invalid status response throws exception
         m.put(
             control_url,
             json=DEVICES.status_put_response_ok(
-                devid=POWERSENSOR.DEVICE_ID, status=CONST.STATUS_OFF_INT
+                devid=POWERSENSOR.DEVICE_ID, status=int(STATUS.OFF)
             ),
         )
 
