@@ -4,7 +4,7 @@ import pytest
 
 import jaraco.abode
 from jaraco.abode.helpers import urls
-import jaraco.abode.helpers.constants as CONST
+import jaraco.abode.devices.status as STATUS
 
 from .mock import login as LOGIN
 from .mock import oauth_claims as OAUTH_CLAIMS
@@ -23,12 +23,12 @@ class TestValve:
         m.post(urls.LOGIN, json=LOGIN.post_response_ok())
         m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
         m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
-        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode='standby'))
         m.get(
             urls.DEVICES,
             json=VALVE.device(
                 devid=VALVE.DEVICE_ID,
-                status=CONST.STATUS_CLOSED,
+                status=STATUS.CLOSED,
                 low_battery=False,
                 no_response=False,
             ),
@@ -42,7 +42,7 @@ class TestValve:
 
         # Test our device
         assert device is not None
-        assert device.status == CONST.STATUS_CLOSED
+        assert device.status == STATUS.CLOSED
         assert not device.battery_low
         assert not device.no_response
         assert not device.is_on
@@ -56,7 +56,7 @@ class TestValve:
             device_url,
             json=VALVE.device(
                 devid=VALVE.DEVICE_ID,
-                status=CONST.STATUS_OPEN,
+                status=STATUS.OPEN,
                 low_battery=True,
                 no_response=True,
             ),
@@ -65,7 +65,7 @@ class TestValve:
         # Refesh device and test changes
         device.refresh()
 
-        assert device.status == CONST.STATUS_OPEN
+        assert device.status == STATUS.OPEN
         assert device.battery_low
         assert device.no_response
         assert device.is_on
@@ -76,12 +76,12 @@ class TestValve:
         m.post(urls.LOGIN, json=LOGIN.post_response_ok())
         m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
         m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
-        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode='standby'))
         m.get(
             urls.DEVICES,
             json=VALVE.device(
                 devid=VALVE.DEVICE_ID,
-                status=CONST.STATUS_CLOSED,
+                status=STATUS.CLOSED,
                 low_battery=False,
                 no_response=False,
             ),
@@ -95,7 +95,7 @@ class TestValve:
 
         # Test that we have our device
         assert device is not None
-        assert device.status == CONST.STATUS_CLOSED
+        assert device.status == STATUS.CLOSED
         assert not device.is_on
 
         # Set up control url response
@@ -103,33 +103,33 @@ class TestValve:
         m.put(
             control_url,
             json=DEVICES.status_put_response_ok(
-                devid=VALVE.DEVICE_ID, status=CONST.STATUS_OPEN_INT
+                devid=VALVE.DEVICE_ID, status=int(STATUS.OPEN)
             ),
         )
 
         # Change the mode to "on"
         assert device.switch_on()
-        assert device.status == CONST.STATUS_OPEN
+        assert device.status == STATUS.OPEN
         assert device.is_on
 
         # Change response
         m.put(
             control_url,
             json=DEVICES.status_put_response_ok(
-                devid=VALVE.DEVICE_ID, status=CONST.STATUS_CLOSED_INT
+                devid=VALVE.DEVICE_ID, status=int(STATUS.CLOSED)
             ),
         )
 
         # Change the mode to "off"
         assert device.switch_off()
-        assert device.status == CONST.STATUS_CLOSED
+        assert device.status == STATUS.CLOSED
         assert not device.is_on
 
         # Test that an invalid status response throws exception
         m.put(
             control_url,
             json=DEVICES.status_put_response_ok(
-                devid=VALVE.DEVICE_ID, status=CONST.STATUS_CLOSED_INT
+                devid=VALVE.DEVICE_ID, status=int(STATUS.CLOSED)
             ),
         )
 
